.. SOM-based C-Q hysteresis analysis documentation master file, created by
   sphinx-quickstart on Thu May  1 10:49:57 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to HySOM's documentation
===========================================================

This is the documentation for the **HySOM** Python package. **HySOM** provides tools for analyzing 2D time series data using Self-Organizing Maps (SOM). This package is tailored for studying concentration - discharge hysteresis loops, although any 2D time series can be used.  

The source code is available on `Github <https://github.com/ArlexMR/HySOM>`_

On this documentation page, you’ll find a quickstart guide with instructions on installation and usage of the package, including sample data. We’ve also written tutorials that walk you through using the General T-Q SOM and training standard SOM for C-Q hysteresis analysis.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Installation <usage/installation>
   Quickstart <usage/quickstart>
   api


